==> pdfadd_2.0.orig.tar.gz: pdfadd-2.0/listdelegate.cpp <==
/***************************************************************************
 *   copyright       : (C) 2012-2014 by Pascal Brachet                     *
 *   http://www.xm1math.net/pdfadd/                                        *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#include <QtGui>
#include <QApplication>
#include <QAbstractItemModel>
#include <QPainter>
#include <QDebug>
#include "listdelegate.h"

void ListDelegate::paint(QPainter *painter, const QStyleOptionViewItem &option,
                          const QModelIndex &index) const
{
    Q_ASSERT(index.isValid());
    const QAbstractItemModel *model = index.model();
    Q_ASSERT(model);

    QStyleOptionViewItem opt = option;

    // set font
    QVariant value = model->data(index, Qt::FontRole);
    if (value.isValid())
        opt.font = qvariant_cast<QFont>(value);

    // set text alignment
    value = model->data(index, Qt::TextAlignmentRole);
    if (value.isValid())
        opt.displayAlignment = QFlag(value.toInt());

    // set text color
    value = model->data(index, Qt::TextColorRole);
    if (value.isValid() && qvariant_cast<QColor>(value).isValid())
        opt.palette.setColor(QPalette::Text, qvariant_cast<QColor>(value));
    
    QString text = model->data(index, Qt::DisplayRole).toString();

        //const bool isSelected = option.state & QStyle::State_Selected;
	const bool isSelected = option.state & QStyle::State_MouseOver;
    if (isSelected)
        QApplication::style()->drawPrimitive(QStyle::PE_PanelItemViewItem, &option, painter);

    painter->save();

    painter->translate(option.rect.topLeft());
    QRect line(0, 0, option.rect.width(), option.rect.height());

//     if (isSelected) 
//     {
//     QColor color1 = QColor::fromRgb(0x69, 0xa6, 0xd9);
//     QColor color2 = QColor::fromRgb(0x14, 0x6b, 0xd4);
//     painter->save();
//     painter->setPen(Qt::NoPen);
//     QLinearGradient linearGradient(0, 0, 0, line.height());
//     linearGradient.setColorAt(0.0, color1);
//     linearGradient.setColorAt(1.0, color2);
//     painter->setBrush(linearGradient);
//     painter->drawRect(line);
//     painter->restore();
//     }

    // text color
    if (isSelected)
        painter->setPen(QPen(option.palette.brush(QPalette::HighlightedText), 0));
    else
        painter->setPen(QPen(option.palette.brush(QPalette::Text), 0));
    
    
    if (opt.font.bold())
	{
    QLinearGradient linearGrad(0, 0, 0, line.height());

    linearGrad.setColorAt(0, QColor(0x99, 0x99, 0x99, 0xFF));
    linearGrad.setColorAt(1, QColor(0xCC, 0xCC, 0xCC, 0xFF));

    painter->fillRect(line, QBrush(linearGrad));

    // borders

    painter->setPen(option.palette.color(QPalette::Mid));
    painter->drawLine(0, line.height()-1, line.width(), line.height()-1);

    // font
    QFont boldFont = painter->font();
    boldFont.setBold(true);
    painter->setFont(boldFont);

    // text size
    QFontMetrics fontMetrics = QFontMetrics(painter->font());
    QSize trackStringSize(fontMetrics.size(Qt::TextSingleLine, text));

    int width = trackStringSize.width();
    const int maxWidth = line.width() - 80;
    if (width > maxWidth) width = maxWidth;

    QPoint textLoc(15, 0);
    QRect trackTextBox(textLoc.x(), textLoc.y(), width, line.height());
    text = fontMetrics.elidedText(text, Qt::ElideRight, trackTextBox.width());

    // text shadow
    painter->setPen(QColor(0, 0, 0, 64));
    painter->drawText(trackTextBox.translated(0, -1), Qt::AlignLeft | Qt::AlignVCenter, text);

    // text
    //painter->setPen(option.palette.color(QPalette::Light));
    painter->setPen(Qt::white);
    painter->drawText(trackTextBox, Qt::AlignLeft | Qt::AlignVCenter, text);
	line.moveBottom(option.fontMetrics.height() * 2);
	painter->translate(0, option.fontMetrics.height() * 2); 
	}
    else
	{
	QFont boldFont = painter->font();
	boldFont.setBold(true);
	boldFont.setPointSize(boldFont.pointSize()*.9);
	painter->setFont(boldFont);
	QString trackString = text;
	QSize trackStringSize(QFontMetrics(painter->font()).size( Qt::TextSingleLine, trackString));
	QPoint textLoc(20, 0);
	QRect trackTextBox(textLoc.x(), textLoc.y(),225, line.height());

	QRect trackRoundedRect = trackTextBox;
	trackRoundedRect.setY((line.height() - trackStringSize.height()) / 2);
		//trackRoundedRect.setX(line.width() - (trackStringSize.width()) / 2);
	trackRoundedRect.setHeight(trackStringSize.height());
	trackRoundedRect.adjust(-10, -6, 10, 6);
	painter->setOpacity(.5);
	painter->setRenderHints(QPainter::Antialiasing, true);
	painter->setBrush(option.palette.window());
	painter->setPen(option.palette.WindowText);

	painter->drawRoundedRect(trackRoundedRect,10,10, Qt::AbsoluteSize);
	painter->drawText(trackTextBox, Qt::AlignCenter, trackString);
	if (isSelected) 
	      {
	      QColor color1 = QColor::fromRgb(0x69, 0xa6, 0xd9);
	      QColor color2 = QColor::fromRgb(0x14, 0x6b, 0xd4);
	      //painter->save();
	      painter->setPen(Qt::NoPen);
	      QLinearGradient linearGradient(0, 0, 0, line.height());
	      linearGradient.setColorAt(0.0, color1);
	      linearGradient.setColorAt(1.0, color2);
	      painter->setBrush(linearGradient);
	      painter->drawRoundedRect(trackRoundedRect,10,10, Qt::AbsoluteSize);
	      //painter->drawRect(line);
	      //painter->restore();
	      }

	//painter->restore();
	}
    painter->setPen(option.palette.color(QPalette::Midlight));
    painter->drawLine(0, line.height()-1, line.width(), line.height()-1);

    painter->restore();

}

QSize ListDelegate::sizeHint(const QStyleOptionViewItem &option,
                              const QModelIndex &index) const
{
int height=option.fontMetrics.height() * 2;
return QSize(225,height);
}

==> pdfadd_2.0.1.orig.tar.gz: pdfadd-2.0.1/listdelegate.cpp <==
/***************************************************************************
 *   copyright       : (C) 2012-2021 by Pascal Brachet                     *
 *   https://www.xm1math.net/pdfadd/                                       *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   @license GPL-2.0+ <https://spdx.org/licenses/GPL-2.0+.html>           *
 ***************************************************************************/

#include <QtGui>
#include <QApplication>
#include <QAbstractItemModel>
#include <QPainter>
#include <QDebug>
#include "listdelegate.h"

void ListDelegate::paint(QPainter *painter, const QStyleOptionViewItem &option,
                          const QModelIndex &index) const
{
    Q_ASSERT(index.isValid());
    const QAbstractItemModel *model = index.model();
    Q_ASSERT(model);

    QStyleOptionViewItem opt = option;

    // set font
    QVariant value = model->data(index, Qt::FontRole);
    if (value.isValid())
        opt.font = qvariant_cast<QFont>(value);

    // set text alignment
    value = model->data(index, Qt::TextAlignmentRole);
    if (value.isValid())
        opt.displayAlignment = QFlag(value.toInt());

    // set text color
    value = model->data(index, Qt::ForegroundRole);
    if (value.isValid() && qvariant_cast<QColor>(value).isValid())
        opt.palette.setColor(QPalette::Text, qvariant_cast<QColor>(value));
    
    QString text = model->data(index, Qt::DisplayRole).toString();

        //const bool isSelected = option.state & QStyle::State_Selected;
	const bool isSelected = option.state & QStyle::State_MouseOver;
    if (isSelected)
        QApplication::style()->drawPrimitive(QStyle::PE_PanelItemViewItem, &option, painter);

    painter->save();

    painter->translate(option.rect.topLeft());
    QRect line(0, 0, option.rect.width(), option.rect.height());

//     if (isSelected) 
//     {
//     QColor color1 = QColor::fromRgb(0x69, 0xa6, 0xd9);
//     QColor color2 = QColor::fromRgb(0x14, 0x6b, 0xd4);
//     painter->save();
//     painter->setPen(Qt::NoPen);
//     QLinearGradient linearGradient(0, 0, 0, line.height());
//     linearGradient.setColorAt(0.0, color1);
//     linearGradient.setColorAt(1.0, color2);
//     painter->setBrush(linearGradient);
//     painter->drawRect(line);
//     painter->restore();
//     }

    // text color
    if (isSelected)
        painter->setPen(QPen(option.palette.brush(QPalette::HighlightedText), 0));
    else
        painter->setPen(QPen(option.palette.brush(QPalette::Text), 0));
    
    
    if (opt.font.bold())
	{
    QLinearGradient linearGrad(0, 0, 0, line.height());

    linearGrad.setColorAt(0, QColor(0x99, 0x99, 0x99, 0xFF));
    linearGrad.setColorAt(1, QColor(0xCC, 0xCC, 0xCC, 0xFF));

    painter->fillRect(line, QBrush(linearGrad));

    // borders

    painter->setPen(option.palette.color(QPalette::Mid));
    painter->drawLine(0, line.height()-1, line.width(), line.height()-1);

    // font
    QFont boldFont = painter->font();
    boldFont.setBold(true);
    painter->setFont(boldFont);

    // text size
    QFontMetrics fontMetrics = QFontMetrics(painter->font());
    QSize trackStringSize(fontMetrics.size(Qt::TextSingleLine, text));

    int width = trackStringSize.width();
    const int maxWidth = line.width() - 80;
    if (width > maxWidth) width = maxWidth;

    QPoint textLoc(15, 0);
    QRect trackTextBox(textLoc.x(), textLoc.y(), width, line.height());
    text = fontMetrics.elidedText(text, Qt::ElideRight, trackTextBox.width());

    // text shadow
    painter->setPen(QColor(0, 0, 0, 64));
    painter->drawText(trackTextBox.translated(0, -1), Qt::AlignLeft | Qt::AlignVCenter, text);

    // text
    //painter->setPen(option.palette.color(QPalette::Light));
    painter->setPen(Qt::white);
    painter->drawText(trackTextBox, Qt::AlignLeft | Qt::AlignVCenter, text);
	line.moveBottom(option.fontMetrics.height() * 2);
	painter->translate(0, option.fontMetrics.height() * 2); 
	}
    else
	{
	QFont boldFont = painter->font();
	boldFont.setBold(true);
	boldFont.setPointSize(boldFont.pointSize()*.9);
	painter->setFont(boldFont);
	QString trackString = text;
	QSize trackStringSize(QFontMetrics(painter->font()).size( Qt::TextSingleLine, trackString));
	QPoint textLoc(20, 0);
	QRect trackTextBox(textLoc.x(), textLoc.y(),225, line.height());

	QRect trackRoundedRect = trackTextBox;
	trackRoundedRect.setY((line.height() - trackStringSize.height()) / 2);
		//trackRoundedRect.setX(line.width() - (trackStringSize.width()) / 2);
	trackRoundedRect.setHeight(trackStringSize.height());
	trackRoundedRect.adjust(-10, -6, 10, 6);
	painter->setOpacity(.5);
	painter->setRenderHints(QPainter::Antialiasing, true);
	painter->setBrush(option.palette.window());
	painter->setPen(option.palette.WindowText);

	painter->drawRoundedRect(trackRoundedRect,10,10, Qt::AbsoluteSize);
	painter->drawText(trackTextBox, Qt::AlignCenter, trackString);
	if (isSelected) 
	      {
	      QColor color1 = QColor::fromRgb(0x69, 0xa6, 0xd9);
	      QColor color2 = QColor::fromRgb(0x14, 0x6b, 0xd4);
	      //painter->save();
	      painter->setPen(Qt::NoPen);
	      QLinearGradient linearGradient(0, 0, 0, line.height());
	      linearGradient.setColorAt(0.0, color1);
	      linearGradient.setColorAt(1.0, color2);
	      painter->setBrush(linearGradient);
	      painter->drawRoundedRect(trackRoundedRect,10,10, Qt::AbsoluteSize);
	      //painter->drawRect(line);
	      //painter->restore();
	      }

	//painter->restore();
	}
    painter->setPen(option.palette.color(QPalette::Midlight));
    painter->drawLine(0, line.height()-1, line.width(), line.height()-1);

    painter->restore();

}

QSize ListDelegate::sizeHint(const QStyleOptionViewItem &option,
                              const QModelIndex &index) const
{
int height=option.fontMetrics.height() * 2;
return QSize(225,height);
}
